package Data::Object::Func::Number;

use Data::Object 'Class';

extends 'Data::Object::Func';

# BUILD
# METHODS

1;

=encoding utf8

=head1 NAME

Data::Object::Func::Number

=cut

=head1 ABSTRACT

Functions for Number Data

=cut

=head1 SYNOPSIS

  use Data::Object::Func::Number;

=cut

=head1 DESCRIPTION

Data::Object::Func::Number is an abstract base class for function classes in
the Data::Object::Func::Number space.

=cut
